import { ParameterLocation, ParameterType, StringParameterType } from './types'
export declare class BaseParameter {
  static isParameter: boolean
  isParameter: boolean
  type: any
  protected params: ParameterType
  generated: boolean
  constructor(params?: ParameterType)
  getValue(): {
    type: any
    description: string
    example: string | number | boolean
    default: string | number | boolean
    enum: string[]
  }
  validate(value: any): any
}
export declare class Arr extends BaseParameter {
  isArr: boolean
  private innerType
  constructor(innerType: any, params?: ParameterType)
  validate(value: any): any
  getValue(): {
    type: string
    items: any
  }
}
export declare class Obj extends BaseParameter {
  isObj: boolean
  private fields
  constructor(fields: Record<string, BaseParameter>, params?: ParameterType)
  validate(value: any): any
  getValue(): {
    type: string
    properties: {}
  }
}
export declare class Num extends BaseParameter {
  type: string
  validate(value: any): any
}
export declare class Int extends Num {
  type: string
  validate(value: any): any
}
export declare class Str extends BaseParameter {
  type: string
  protected params: StringParameterType
  constructor(params?: StringParameterType)
  validate(value: any): any
  getValue(): {
    format: string
    type: any
    description: string
    example: string | number | boolean
    default: string | number | boolean
    enum: string[]
  }
}
export declare class DateTime extends Str {
  type: string
  protected params: StringParameterType
  constructor(params?: StringParameterType)
}
export declare class DateOnly extends Str {
  type: string
  protected params: StringParameterType
  constructor(params?: StringParameterType)
}
export declare class Bool extends BaseParameter {
  type: string
  private validValues
  validate(value: any): any
}
export declare class Enumeration {
  isEnum: boolean
  values: Record<string, any>
  keys: any
  constructor(values: Record<string, any>)
}
export declare class Parameter {
  location: string
  private rawType
  type: BaseParameter
  params: ParameterLocation
  constructor(location: string, rawType: any, params: ParameterLocation)
  getType(type: any, params: ParameterLocation): any
  getValue(): {
    description: string
    required: boolean
    schema: Record<string, any>
    name: string
    in: string
  }
  validate(value: any): any
}
export declare class Resp extends Parameter {
  constructor(location: string, rawType: any, params: ParameterLocation)
  getValue(): {
    description: string
    content: {}
  }
}
export declare function Query(type: any, params?: ParameterLocation): Parameter
export declare function Path(type: any, params?: ParameterLocation): Parameter
export declare function Header(type: any, params?: ParameterLocation): Parameter
export declare function Cookie(type: any, params?: ParameterLocation): Parameter
export declare function extractParameter(request: any, query: Record<string, any>, name: string, location: string): any
export declare function extractQueryParameters(request: any): Record<string, any>
export declare function Required(param: Parameter): Parameter
export declare function removeUndefinedFields(obj: Record<string, any>): Record<string, any>
export declare function Body({
  description,
  contentType,
  schema,
}?: {
  description?: any
  contentType?: string
  schema?: {}
}): {
  description: any
  content: {}
}
export declare function getFormatedParameters(params: Record<string, Parameter> | Parameter[]): any[]
